@@ -82,6 +82,17 @@ class EclipseJavaIDETests(LargeFrameworkTests):
         self.wait_and_close()
 
 
+class EclipseJEEIDETests(EclipseJavaIDETests):
+    """The Eclipse distribution from the IDE collection."""
+
+    def setUp(self):
+        super().setUp()
+        self.installed_path = os.path.join(self.install_base_path, "ide", "eclipse-jee")
+        self.desktop_filename = "eclipse-jee.desktop"
+        self.command_args = '{} ide eclipse-jee'.format(UMAKE)
+        self.name = "Eclipse JEE"
+
+
 class EclipsePHPIDETests(EclipseJavaIDETests):
     """The Eclipse distribution from the IDE collection."""
 
@@ -114,11 +125,13 @@ class IdeaIDETests(LargeFrameworkTests):
     def setUp(self):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "idea")
-        self.desktop_filename = 'jetbrains-idea.desktop'
+        self.desktop_filename = 'jetbrains-idea-ce.desktop'
+        self.command_args = '{} ide idea'.format(UMAKE)
+        self.name = 'Idea'
 
     def test_default_install(self):
         """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide idea'.format(UMAKE)))
+        self.child = spawn_process(self.command(self.command_args))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
         self.child.sendline("")
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
@@ -138,13 +151,47 @@ class IdeaIDETests(LargeFrameworkTests):
         proc.wait(self.TIMEOUT_STOP)
 
         # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide idea'.format(UMAKE)))
-        self.expect_and_no_warn("Idea is already installed.*\[.*\] ")
+        self.child = spawn_process(self.command(self.command_args))
+        self.expect_and_no_warn("{} is already installed.*\[.*\] ".format(self.name))
         self.child.sendline()
         self.wait_and_close()
 
+    def test_eap_install(self):
+        self.installed_path += '-eap'
+        self.desktop_filename.replace('.desktop', '-eap.desktop')
+        self.command_args += ' --eap'
+        self.name += ' EAP'
 
-class IdeaUltimateIDETests(LargeFrameworkTests):
+        self.child = spawn_process(self.command(self.command_args))
+        result = self.expect_and_no_warn(["ERROR: No EAP version available.*\[.*\]",
+                                          "Choose installation path: {}".format(self.installed_path)])
+        if result == 1:
+            self.child.sendline("")
+            self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
+            self.wait_and_close()
+
+            # we have an installed launcher, added to the launcher and an icon file
+            self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
+            self.assert_exec_exists()
+            self.assert_icon_exists()
+            self.assert_exec_link_exists()
+
+            # launch it, send SIGTERM and check that it exits fine
+            proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
+                                    stderr=subprocess.DEVNULL)
+
+            self.check_and_kill_process(self.exec_path,
+                                        wait_before=self.TIMEOUT_START, send_sigkill=True)
+            proc.wait(self.TIMEOUT_STOP)
+
+            # ensure that it's detected as installed:
+            self.child = spawn_process(self.command(self.command_args))
+            self.expect_and_no_warn("{} is already installed.*\[.*\] ".format(self.name))
+            self.child.sendline()
+            self.wait_and_close()
+
+
+class IdeaUltimateIDETests(IdeaIDETests):
     """IntelliJ Idea Ultimate from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -155,38 +202,11 @@ class IdeaUltimateIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "idea-ultimate")
         self.desktop_filename = 'jetbrains-idea.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide idea-ultimate'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide idea-ultimate'.format(UMAKE)))
-        self.expect_and_no_warn("Idea Ultimate is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide idea-ultimate'.format(UMAKE)
+        self.name = 'Idea Ultimate'
 
 
-class PyCharmIDETests(LargeFrameworkTests):
+class PyCharmIDETests(IdeaIDETests):
     """PyCharm from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -196,39 +216,12 @@ class PyCharmIDETests(LargeFrameworkTests):
     def setUp(self):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "pycharm")
-        self.desktop_filename = 'jetbrains-pycharm.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide pycharm'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide pycharm'.format(UMAKE)))
-        self.expect_and_no_warn("PyCharm is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.desktop_filename = 'jetbrains-pycharm-ce.desktop'
+        self.command_args = '{} ide pycharm'.format(UMAKE)
+        self.name = 'PyCharm'
 
 
-class PyCharmEducationalIDETests(LargeFrameworkTests):
+class PyCharmEducationalIDETests(IdeaIDETests):
     """PyCharm Educational from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -238,39 +231,12 @@ class PyCharmEducationalIDETests(LargeFrameworkTests):
     def setUp(self):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "pycharm-educational")
-        self.desktop_filename = 'jetbrains-pycharm.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide pycharm-educational'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide pycharm-educational'.format(UMAKE)))
-        self.expect_and_no_warn("PyCharm Educational is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.desktop_filename = 'jetbrains-pycharm-edu.desktop'
+        self.command_args = '{} ide pycharm-educational'.format(UMAKE)
+        self.name = 'PyCharm Educational'
 
 
-class PyCharmProfessionalIDETests(LargeFrameworkTests):
+class PyCharmProfessionalIDETests(IdeaIDETests):
     """PyCharm Professional from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -281,38 +247,11 @@ class PyCharmProfessionalIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "pycharm-professional")
         self.desktop_filename = 'jetbrains-pycharm.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide pycharm-professional'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide pycharm-professional'.format(UMAKE)))
-        self.expect_and_no_warn("PyCharm Professional is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide pycharm-professional'.format(UMAKE)
+        self.name = 'PyCharm Professional'
 
 
-class RubyMineIDETests(LargeFrameworkTests):
+class RubyMineIDETests(IdeaIDETests):
     """RubyMine from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -323,38 +262,11 @@ class RubyMineIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "rubymine")
         self.desktop_filename = 'jetbrains-rubymine.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide rubymine'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide rubymine'.format(UMAKE)))
-        self.expect_and_no_warn("RubyMine is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide rubymine'.format(UMAKE)
+        self.name = 'RubyMine'
 
 
-class WebStormIDETests(LargeFrameworkTests):
+class WebStormIDETests(IdeaIDETests):
     """WebStorm from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -365,38 +277,11 @@ class WebStormIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "webstorm")
         self.desktop_filename = 'jetbrains-webstorm.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide webstorm'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide webstorm'.format(UMAKE)))
-        self.expect_and_no_warn("WebStorm is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide webstorm'.format(UMAKE)
+        self.name = 'WebStorm'
 
 
-class PhpStormIDETests(LargeFrameworkTests):
+class PhpStormIDETests(IdeaIDETests):
     """PhpStorm from the IDE collection."""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -407,38 +292,11 @@ class PhpStormIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "phpstorm")
         self.desktop_filename = 'jetbrains-phpstorm.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide phpstorm'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide phpstorm'.format(UMAKE)))
-        self.expect_and_no_warn("PhpStorm is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide phpstorm'.format(UMAKE)
+        self.name = 'PhpStorm'
 
 
-class CLionIDETests(LargeFrameworkTests):
+class CLionIDETests(IdeaIDETests):
     """CLion test from the IDE collection"""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -449,43 +307,11 @@ class CLionIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "clion")
         self.desktop_filename = 'jetbrains-clion.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-
-        # only an amd64 framework
-        if platform.machine() != "x86_64":
-            return
-
-        self.child = spawn_process(self.command('{} ide clion'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide clion'.format(UMAKE)))
-        self.expect_and_no_warn("CLion is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide clion'.format(UMAKE)
+        self.name = 'CLion'
 
 
-class DataGripIDETests(LargeFrameworkTests):
+class DataGripIDETests(IdeaIDETests):
     """Datagrip test from the IDE collection"""
 
     TIMEOUT_INSTALL_PROGRESS = 120
@@ -496,35 +322,8 @@ class DataGripIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "datagrip")
         self.desktop_filename = 'jetbrains-datagrip.desktop'
-
-    def test_default_install(self):
-        """Install from scratch test case"""
-        self.child = spawn_process(self.command('{} ide datagrip'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.child.sendline("")
-        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_close()
-
-        logger.info("Installed, running...")
-
-        # we have an installed launcher, added to the launcher and an icon file
-        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assert_exec_exists()
-        self.assert_icon_exists()
-        self.assert_exec_link_exists()
-
-        # launch it, send SIGTERM and check that it exits fine
-        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
-                                stderr=subprocess.DEVNULL)
-
-        self.check_and_kill_process(["java", self.installed_path], wait_before=self.TIMEOUT_START)
-        proc.wait(self.TIMEOUT_STOP)
-
-        # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide datagrip'.format(UMAKE)))
-        self.expect_and_no_warn("DataGrip is already installed.*\[.*\] ")
-        self.child.sendline()
-        self.wait_and_close()
+        self.command_args = '{} ide datagrip'.format(UMAKE)
+        self.name = 'DataGrip'
 
 
 class ArduinoIDETests(LargeFrameworkTests):
@@ -648,7 +447,7 @@ class VisualStudioCodeTest(LargeFrameworkTests):
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
                                 stderr=subprocess.DEVNULL)
 
-        self.check_and_kill_process(["Code", self.installed_path],
+        self.check_and_kill_process([self.exec_path, self.installed_path],
                                     wait_before=self.TIMEOUT_START, send_sigkill=True)
         proc.wait(self.TIMEOUT_STOP)
 
@@ -670,11 +469,12 @@ class LightTableTest(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.join(self.install_base_path, "ide", "lighttable")
         self.desktop_filename = "lighttable.desktop"
+        self.command_args = '{} ide lighttable'.format(UMAKE)
 
     def test_default_install(self):
         """Install LightTable from scratch test case"""
 
-        self.child = spawn_process(self.command('{} ide lighttable'.format(UMAKE)))
+        self.child = spawn_process(self.command(self.command_args))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
         self.child.sendline("")
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
@@ -695,7 +495,7 @@ class LightTableTest(LargeFrameworkTests):
         proc.wait(self.TIMEOUT_STOP)
 
         # ensure that it's detected as installed:
-        self.child = spawn_process(self.command('{} ide lighttable'.format(UMAKE)))
+        self.child = spawn_process(self.command(self.command_args))
         self.expect_and_no_warn("LightTable is already installed.*\[.*\] ")
         self.child.sendline()
         self.wait_and_close()
@@ -722,6 +522,7 @@ class SpringToolsSuiteTest(LargeFrameworkTests):
 
     def test_default_install(self):
         """Install STS from scratch test case"""
+        return  # framework disabled
 
         self.child = spawn_process(self.command(self.command_args))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
