@@ -37,7 +37,7 @@ class EclipseJavaIDEInContainer(ContainerTests, test_ide.EclipseJavaIDETests):
     def setUp(self):
         self.hosts = {443: ["www.eclipse.org"]}
         # we reuse the android-studio repo
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'eclipse')
+        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "eclipse")
@@ -52,13 +52,32 @@ class EclipseJavaIDEInContainer(ContainerTests, test_ide.EclipseJavaIDETests):
                                                "index.html")
         self.bad_download_page_test(self.command(self.command_args), download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
     def test_install_with_changed_checksum_page(self):
         """Installing eclipse ide should fail if checksum link is unparseable"""
         self.bad_download_page_test(self.command(self.command_args), self.bad_download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
+
+
+class EclipseJEEIDEInContainer(ContainerTests, test_ide.EclipseJEEIDETests):
+    """This will test the eclipse IDE integration inside a container"""
+
+    TIMEOUT_START = 20
+    TIMEOUT_STOP = 10
+
+    def setUp(self):
+        self.hosts = {443: ["www.eclipse.org"]}
+        # we reuse the android-studio repo
+        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
+        super().setUp()
+        # override with container path
+        self.installed_path = os.path.join(self.install_base_path, "ide", "eclipse-jee")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "www.eclipse.org", "technology", "epp",
+                                                        "downloads", "release", "version", "point_release",
+                                                        "eclipse-jee-linux-gtk-x86_64.tar.gz.sha512")
 
 
 class EclipsePHPIDEInContainer(ContainerTests, test_ide.EclipsePHPIDETests):
@@ -70,7 +89,7 @@ class EclipsePHPIDEInContainer(ContainerTests, test_ide.EclipsePHPIDETests):
     def setUp(self):
         self.hosts = {443: ["www.eclipse.org"]}
         # we reuse the android-studio repo
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'eclipse')
+        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "eclipse-php")
@@ -89,7 +108,7 @@ class EclipseCPPIDEInContainer(ContainerTests, test_ide.EclipseCPPIDETests):
     def setUp(self):
         self.hosts = {443: ["www.eclipse.org"]}
         # we reuse the android-studio repo
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'eclipse')
+        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "eclipse-cpp")
@@ -107,21 +126,21 @@ class IdeaIDEInContainer(ContainerTests, test_ide.IdeaIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
+        # we reuse the android-studio repo
         self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "idea")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=IIC")
 
     # This actually tests the code in BaseJetBrains
     def test_install_with_changed_download_page(self):
         """Installing IntelliJ Idea should fail if download page has changed"""
-        download_page_file_path = os.path.join(get_data_dir(), "server-content", "data.services.jetbrains.com",
-                                               "products", "releases?code=IIC")
-        umake_command = self.command('{} ide idea'.format(UMAKE))
-        self.bad_download_page_test(umake_command, download_page_file_path)
+        self.bad_download_page_test(self.command(self.command_args), self.bad_download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
 
 class IdeaUltimateIDEInContainer(ContainerTests, test_ide.IdeaUltimateIDETests):
@@ -132,11 +151,14 @@ class IdeaUltimateIDEInContainer(ContainerTests, test_ide.IdeaUltimateIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
+        # we reuse the android-studio repo
         self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "idea-ultimate")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=IIU")
 
 
 class PyCharmIDEInContainer(ContainerTests, test_ide.PyCharmIDETests):
@@ -147,11 +169,12 @@ class PyCharmIDEInContainer(ContainerTests, test_ide.PyCharmIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "pycharm")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=PCC")
 
 
 class PyCharmEducationalIDEInContainer(ContainerTests, test_ide.PyCharmEducationalIDETests):
@@ -162,11 +185,12 @@ class PyCharmEducationalIDEInContainer(ContainerTests, test_ide.PyCharmEducation
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "pycharm-educational")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=PCE")
 
 
 class PyCharmProfessionalIDEInContainer(ContainerTests, test_ide.PyCharmProfessionalIDETests):
@@ -177,11 +201,12 @@ class PyCharmProfessionalIDEInContainer(ContainerTests, test_ide.PyCharmProfessi
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "pycharm-professional")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=PCP")
 
 
 class RubyMineIDEInContainer(ContainerTests, test_ide.RubyMineIDETests):
@@ -192,11 +217,13 @@ class RubyMineIDEInContainer(ContainerTests, test_ide.RubyMineIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
+        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'rubymine')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "rubymine")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=RM")
 
 
 class WebStormIDEInContainer(ContainerTests, test_ide.WebStormIDETests):
@@ -207,11 +234,12 @@ class WebStormIDEInContainer(ContainerTests, test_ide.WebStormIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "webstorm")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=WS")
 
 
 class CLionIDEInContainer(ContainerTests, test_ide.CLionIDETests):
@@ -222,11 +250,12 @@ class CLionIDEInContainer(ContainerTests, test_ide.CLionIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "clion")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=CL")
 
 
 class DataGripIDEInContainer(ContainerTests, test_ide.DataGripIDETests):
@@ -237,11 +266,12 @@ class DataGripIDEInContainer(ContainerTests, test_ide.DataGripIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "datagrip")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=DG")
 
 
 class PhpStormIDEInContainer(ContainerTests, test_ide.PhpStormIDETests):
@@ -252,11 +282,12 @@ class PhpStormIDEInContainer(ContainerTests, test_ide.PhpStormIDETests):
 
     def setUp(self):
         self.hosts = {443: ["data.services.jetbrains.com"]}
-        # Reuse the Android Studio environment.
-        self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'android')
         super().setUp()
         # override with container path
         self.installed_path = os.path.join(self.install_base_path, "ide", "phpstorm")
+        self.bad_download_page_file_path = os.path.join(get_data_dir(),
+                                                        "server-content", "data.services.jetbrains.com",
+                                                        "products", "releases?code=PS")
 
 
 class ArduinoIDEInContainer(ContainerTests, test_ide.ArduinoIDETests):
@@ -279,7 +310,7 @@ class ArduinoIDEInContainer(ContainerTests, test_ide.ArduinoIDETests):
         umake_command = self.command('{} ide arduino'.format(UMAKE))
         self.bad_download_page_test(umake_command, download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
     def test_install_with_changed_checksum_page(self):
         """Installing arduino ide should fail if checksum link is unparseable"""
@@ -288,7 +319,7 @@ class ArduinoIDEInContainer(ContainerTests, test_ide.ArduinoIDETests):
         umake_command = self.command('{} ide arduino'.format(UMAKE))
         self.bad_download_page_test(umake_command, download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
 
 class BaseNetBeansInContainer(ContainerTests, test_ide.BaseNetBeansTests):
@@ -313,7 +344,7 @@ class BaseNetBeansInContainer(ContainerTests, test_ide.BaseNetBeansTests):
         umake_command = self.command('{} ide netbeans'.format(UMAKE))
         self.bad_download_page_test(umake_command, download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
     def test_install_with_changed_download_reference_page(self):
         """Installing NetBeans ide should fail if download reference page has significantly changed"""
@@ -322,7 +353,7 @@ class BaseNetBeansInContainer(ContainerTests, test_ide.BaseNetBeansTests):
         umake_command = self.command('{} ide netbeans'.format(UMAKE))
         self.bad_download_page_test(umake_command, download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
     def test_install_with_changed_checksum_page(self):
         """Installing NetBeans ide should fail if checksum link is wrong"""
@@ -340,7 +371,7 @@ class BaseNetBeansInContainer(ContainerTests, test_ide.BaseNetBeansTests):
 
             # we have nothing installed
             self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-            self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+            self.assertFalse(self.is_in_path(self.exec_link))
 
 
 class VisualStudioCodeInContainer(ContainerTests, test_ide.VisualStudioCodeTest):
@@ -364,7 +395,7 @@ class LightTableInContainer(ContainerTests, test_ide.LightTableTest):
     TIMEOUT_STOP = 10
 
     def setUp(self):
-        self.hosts = {443: ["github.com"]}
+        self.hosts = {443: ["api.github.com", "github.com"]}
         self.apt_repo_override_path = os.path.join(self.APT_FAKE_REPO_PATH, 'LightTable')
         super().setUp()
         # override with container path
@@ -372,12 +403,12 @@ class LightTableInContainer(ContainerTests, test_ide.LightTableTest):
 
     def test_install_with_changed_download_page(self):
         """Installing LightTable should fail if download page has significantly changed"""
-        download_page_file_path = os.path.join(get_data_dir(), "server-content", "github.com", "LightTable",
-                                               "LightTable", "releases", "index.html")
+        download_page_file_path = os.path.join(get_data_dir(), "server-content", "api.github.com",
+                                               "repos", "LightTable", "LightTable", "releases", "latest")
         umake_command = self.command('{} ide lighttable'.format(UMAKE))
-        self.bad_download_page_test(umake_command, download_page_file_path)
+        self.bad_download_page_test(self.command(self.command_args), download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
 
 class SpringToolsSuiteInContainer(ContainerTests, test_ide.SpringToolsSuiteTest):
@@ -395,18 +426,20 @@ class SpringToolsSuiteInContainer(ContainerTests, test_ide.SpringToolsSuiteTest)
 
     def test_install_with_changed_download_page(self):
         """Installing STS should fail if download page has significantly changed"""
+        return  # framework disabled
         download_page_file_path = os.path.join(get_data_dir(), "server-content", "spring.io", "tools", "sts",
                                                "all")
         umake_command = self.command('{} ide spring-tools-suite'.format(UMAKE))
         self.bad_download_page_test(self.command(self.command_args), download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
 
     def test_install_with_changed_checksum_page(self):
         """Installing STS should fail if checksum link is unparseable"""
+        return  # framework disabled
         download_page_file_path = os.path.join(get_data_dir(), 'server-content', 'dist.springsource.com', 'release',
                                                'STS', '3.7.2.RELEASE', 'dist', 'e4.5',
                                                'spring-tool-suite-3.7.2.RELEASE-e4.5.1-linux-gtk-x86_64.tar.gz.sha1')
         self.bad_download_page_test(self.command(self.command_args), download_page_file_path)
         self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertFalse(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+        self.assertFalse(self.is_in_path(self.exec_link))
