@@ -77,7 +77,6 @@ class BaseEclipse(umake.frameworks.baseinstaller.BaseInstaller, metaclass=ABCMet
             kwargs["required_files_path"] = current_required_files_path
         download_page = 'https://www.eclipse.org/downloads/'
         kwargs["download_page"] = download_page
-        kwargs["exec_rel_path"] = "eclipse"
         super().__init__(*args, **kwargs)
         self.icon_url = os.path.join(self.download_page, "images", self.icon_filename)
         self.bits = '' if platform.machine() == 'i686' else 'x86_64'
@@ -184,10 +183,25 @@ class EclipseJava(BaseEclipse):
                          dir_to_decompress_in_tarball='eclipse',
                          desktop_filename='eclipse-java.desktop',
                          category=category, only_on_archs=['i386', 'amd64'],
-                         packages_requirements=['openjdk-7-jdk'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          icon_filename='java.png')
 
 
+class EclipseJEE(BaseEclipse):
+    """The Eclipse JEE Edition distribution."""
+    download_keyword = 'eclipse-jee'
+    executable = 'eclipse'
+
+    def __init__(self, category):
+        super().__init__(name="Eclipse JEE",
+                         description=_("Eclipse JEE IDE"),
+                         dir_to_decompress_in_tarball='eclipse',
+                         desktop_filename='eclipse-jee.desktop',
+                         category=category, only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
+                         icon_filename='javaee.png')
+
+
 class EclipsePHP(BaseEclipse):
     """The Eclipse PHP Edition distribution."""
     download_keyword = 'eclipse-php'
@@ -199,7 +213,7 @@ class EclipsePHP(BaseEclipse):
                          dir_to_decompress_in_tarball='eclipse',
                          desktop_filename='eclipse-php.desktop',
                          category=category, only_on_archs=['i386', 'amd64'],
-                         packages_requirements=['openjdk-7-jdk'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          icon_filename='php.png')
 
 
@@ -214,7 +228,7 @@ class EclipseCPP(BaseEclipse):
                          dir_to_decompress_in_tarball='eclipse',
                          desktop_filename='eclipse-cpp.desktop',
                          category=category, only_on_archs=['i386', 'amd64'],
-                         packages_requirements=['openjdk-7-jdk'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          icon_filename='cdt.png')
 
 
@@ -256,7 +270,13 @@ class BaseJetBrains(umake.frameworks.baseinstaller.BaseInstaller, metaclass=ABCM
             key, content = json.loads(page.buffer.read().decode()).popitem()
             download_url = content[0]['downloads']['linux']['link']
             checksum_url = content[0]['downloads']['linux']['checksumLink']
-        except (json.JSONDecodeError, IndexError):
+        except (IndexError):
+            if '&type=eap' in self.download_page:
+                logger.error("No EAP version available.")
+            else:
+                logger.error("Can't parse the download URL from the download page.")
+            UI.return_main_screen(status_code=1)
+        except (json.JSONDecodeError):
             logger.error("Can't parse the download URL from the download page.")
             UI.return_main_screen(status_code=1)
         logger.debug("Found download URL: " + download_url)
@@ -284,12 +304,27 @@ class BaseJetBrains(umake.frameworks.baseinstaller.BaseInstaller, metaclass=ABCM
         comment = self.description + " (UDTC)"
         categories = "Development;IDE;"
         create_launcher(self.desktop_filename,
-                        get_application_desktop_file(name=self.description,
+                        get_application_desktop_file(name=self.name,
                                                      icon_path=icon_path,
                                                      exec='"{}" %f'.format(self.exec_path),
                                                      comment=comment,
                                                      categories=categories))
 
+    def install_framework_parser(self, parser):
+        this_framework_parser = super().install_framework_parser(parser)
+        this_framework_parser.add_argument('--eap', action="store_true",
+                                           help=_("Install EAP version if available"))
+        return this_framework_parser
+
+    def run_for(self, args):
+        if args.eap:
+            self.download_page += '&type=eap'
+            self.name += " EAP"
+            self.description += " EAP"
+            self.desktop_filename = self.desktop_filename.replace(".desktop", "-eap.desktop")
+            self.install_path += "-eap"
+        super().run_for(args)
+
 
 class PyCharm(BaseJetBrains):
     """The JetBrains PyCharm Community Edition distribution."""
@@ -300,9 +335,9 @@ class PyCharm(BaseJetBrains):
         super().__init__(name="PyCharm",
                          description=_("PyCharm Community Edition"),
                          category=category, only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['python', 'python3'],
                          dir_to_decompress_in_tarball='pycharm-community-*',
-                         desktop_filename='jetbrains-pycharm.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
+                         desktop_filename='jetbrains-pycharm-ce.desktop',
                          icon_filename='pycharm.png')
 
 
@@ -315,9 +350,9 @@ class PyCharmEducational(BaseJetBrains):
         super().__init__(name="PyCharm Educational",
                          description=_("PyCharm Educational Edition"),
                          category=category, only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['python', 'python3'],
                          dir_to_decompress_in_tarball='pycharm-edu*',
-                         desktop_filename='jetbrains-pycharm.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
+                         desktop_filename='jetbrains-pycharm-edu.desktop',
                          icon_filename='pycharm.png')
 
 
@@ -330,9 +365,9 @@ class PyCharmProfessional(BaseJetBrains):
         super().__init__(name="PyCharm Professional",
                          description=_("PyCharm Professional Edition"),
                          category=category, only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['python', 'python3'],
                          dir_to_decompress_in_tarball='pycharm-*',
                          desktop_filename='jetbrains-pycharm.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='pycharm.png')
 
 
@@ -345,9 +380,9 @@ class Idea(BaseJetBrains):
         super().__init__(name="Idea",
                          description=_("IntelliJ IDEA Community Edition"),
                          category=category, only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          dir_to_decompress_in_tarball='idea-IC-*',
-                         desktop_filename='jetbrains-idea.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
+                         desktop_filename='jetbrains-idea-ce.desktop',
                          icon_filename='idea.png')
 
 
@@ -360,9 +395,9 @@ class IdeaUltimate(BaseJetBrains):
         super().__init__(name="Idea Ultimate",
                          description=_("IntelliJ IDEA"),
                          category=category, only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          dir_to_decompress_in_tarball='idea-IU-*',
                          desktop_filename='jetbrains-idea.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='idea.png')
 
 
@@ -376,9 +411,9 @@ class RubyMine(BaseJetBrains):
                          description=_("Ruby on Rails IDE"),
                          category=category,
                          only_on_archs=['i386', 'amd64'],
+                         packages_requirements=['ruby'],
                          dir_to_decompress_in_tarball='RubyMine-*',
                          desktop_filename='jetbrains-rubymine.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='rubymine.png')
 
 
@@ -394,7 +429,6 @@ class WebStorm(BaseJetBrains):
                          only_on_archs=['i386', 'amd64'],
                          dir_to_decompress_in_tarball='WebStorm-*',
                          desktop_filename='jetbrains-webstorm.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='webstorm.svg')
 
 
@@ -410,7 +444,6 @@ class PhpStorm(BaseJetBrains):
                          only_on_archs=['i386', 'amd64'],
                          dir_to_decompress_in_tarball='PhpStorm-*',
                          desktop_filename='jetbrains-phpstorm.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='webide.png')
 
 
@@ -426,7 +459,6 @@ class CLion(BaseJetBrains):
                          only_on_archs=['amd64'],
                          dir_to_decompress_in_tarball='clion-*',
                          desktop_filename='jetbrains-clion.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='clion.svg')
 
 
@@ -442,7 +474,6 @@ class DataGrip(BaseJetBrains):
                          only_on_archs=['i386', 'amd64'],
                          dir_to_decompress_in_tarball='DataGrip-*',
                          desktop_filename='jetbrains-datagrip.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='product.png')
 
 
@@ -469,7 +500,7 @@ class Arduino(umake.frameworks.baseinstaller.BaseInstaller):
                          download_page='http://www.arduino.cc/en/Main/Software',
                          dir_to_decompress_in_tarball='arduino-*',
                          desktop_filename='arduino.desktop',
-                         packages_requirements=['openjdk-7-jdk', 'jayatana', 'gcc-avr', 'avr-libc'],
+                         packages_requirements=['gcc-avr', 'avr-libc'],
                          need_root_access=not self.was_in_arduino_group,
                          required_files_path=["arduino"])
         self.scraped_checksum_url = None
@@ -598,7 +629,7 @@ class BaseNetBeans(umake.frameworks.baseinstaller.BaseInstaller):
                          download_page="https://netbeans.org/downloads/zip.html",
                          dir_to_decompress_in_tarball="netbeans*",
                          desktop_filename="netbeans{}.desktop".format(flavour),
-                         packages_requirements=['openjdk-7-jdk', 'jayatana'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          required_files_path=[os.path.join("bin", "netbeans")])
 
     @MainLoop.in_mainloop_thread
@@ -692,7 +723,7 @@ class VisualStudioCode(umake.frameworks.baseinstaller.BaseInstaller):
                          category=category, only_on_archs=['i386', 'amd64'], expect_license=True,
                          download_page="https://code.visualstudio.com/License",
                          desktop_filename="visual-studio-code.desktop",
-                         required_files_path=["Code"],
+                         required_files_path=["code"],
                          dir_to_decompress_in_tarball="VSCode-linux-*",
                          packages_requirements=["libgtk2.0-0"])
 
@@ -700,7 +731,7 @@ class VisualStudioCode(umake.frameworks.baseinstaller.BaseInstaller):
         """Parse Android Studio download page for license"""
         if 'SOFTWARE LICENSE TERMS' in line:
             in_license = True
-        if in_license and "<strong>*   *   *</strong>" in line:
+        if in_license and "</div>" in line:
             in_license = False
 
         if in_license:
@@ -729,25 +760,33 @@ class LightTable(umake.frameworks.baseinstaller.BaseInstaller):
     def __init__(self, category):
         super().__init__(name="LightTable", description=_("LightTable code editor"),
                          category=category, only_on_archs=['amd64'],
-                         download_page="https://github.com/LightTable/LightTable/releases",
+                         download_page="https://api.github.com/repos/LightTable/LightTable/releases/latest",
                          desktop_filename="lighttable.desktop",
                          required_files_path=["LightTable"],
                          dir_to_decompress_in_tarball="lighttable-*",
                          checksum_type=ChecksumType.md5)
 
-    def parse_download_link(self, line, in_download):
-        """Parse LightTable download links"""
-        url, md5 = (None, None)
-        if '<li>Ubuntu' in line:
-            in_download = True
-            p = re.search(r'(\w+)</li>', line)
-            with suppress(AttributeError):
-                md5 = p.group(1)
-        if in_download is True and "-linux.tar.gz" in line:
-            p = re.search(r'href="(.*.-linux.tar.gz)"', line)
-            with suppress(AttributeError):
-                url = "https://github.com" + p.group(1)
-        return ((url, md5), in_download)
+    @MainLoop.in_mainloop_thread
+    def get_metadata_and_check_license(self, result):
+        logger.debug("Fetched download page, parsing.")
+        page = result[self.download_page]
+        error_msg = page.error
+        if error_msg:
+            logger.error("An error occurred while downloading {}: {}".format(self.download_page, error_msg))
+            UI.return_main_screen(status_code=1)
+
+        try:
+            assets = json.loads(page.buffer.read().decode())["assets"]
+            for asset in assets:
+                if "linux" in asset["browser_download_url"]:
+                    download_url = asset["browser_download_url"]
+        except (json.JSONDecodeError, IndexError):
+            logger.error("Can't parse the download URL from the download page.")
+            UI.return_main_screen(status_code=1)
+        logger.debug("Found download URL: " + download_url)
+
+        self.download_requests.append(DownloadItem(download_url, None))
+        self.start_download_and_install()
 
     def post_install(self):
         """Create the LightTable Code launcher"""
@@ -761,13 +800,14 @@ class LightTable(umake.frameworks.baseinstaller.BaseInstaller):
 
 class SpringToolsSuite(umake.frameworks.baseinstaller.BaseInstaller):
     def __init__(self, category):
+        return
         super().__init__(name="Spring Tools Suite",
                          description=_("Spring Tools Suite IDE"),
                          download_page="https://spring.io/tools/sts/all",
                          dir_to_decompress_in_tarball='sts-bundle/sts-*',
                          desktop_filename='STS.desktop',
                          category=category, only_on_archs=['i386', 'amd64'],
-                         packages_requirements=['openjdk-7-jdk'],
+                         packages_requirements=['openjdk-7-jdk | openjdk-8-jdk'],
                          icon_filename='icon.xpm',
                          required_files_path=["STS"])
         self.arch = '' if platform.machine() == 'i686' else '-x86_64'
@@ -825,7 +865,7 @@ class SpringToolsSuite(umake.frameworks.baseinstaller.BaseInstaller):
             logger.error("Download page changed its syntax or is not parsable (missing url)")
             UI.return_main_screen(status_code=1)
         if sha1 is None:
-            logger.error("Download page changed its syntax or is not parsable (missing sha512)")
+            logger.error("Download page changed its syntax or is not parsable (missing checksum)")
             UI.return_main_screen(status_code=1)
         logger.debug("Found download link for {}, checksum: {}".format(url, sha1))
         self.download_requests.append(DownloadItem(url, Checksum(ChecksumType.sha1, sha1)))
